@@ -38,7 +38,8 @@ class Notation(object):
             save_dir = global_path
 
         if save_dir:
-            print("ClusterTools: using config in {}".format(save_dir))
+            if verbose:
+                print("ClusterTools: using config in {}".format(save_dir))
             with open(save_dir, 'r') as f:
                 key_data = yaml.load(f, Loader=yaml.FullLoader)
             for key, item in key_data.items():
@@ -83,7 +84,7 @@ class Notation(object):
     def P(cls, title, content="", verbose=False, **kwargs):
         cls._class_name = cls.__name__
         cls._user_dir = os.path.expanduser('~')
-        cls._yaml_bind(cls, verbose, kwargs.get('path', ''))
+        cls._yaml_bind(cls, verbose=False, path=kwargs.get('path', ''))
         cls._send(cls, title, cls._load_content(content), **kwargs)
         return True
         
